@@ -22,7 +22,7 @@ ALINE alignment, similarity, and distance
 from copy import deepcopy
 
 from numpy import NINF
-from numpy import float as np_float
+from numpy import float_ as np_float
 from numpy import zeros as np_zeros
 
 from ._distance import _Distance
