@@ -770,10 +770,10 @@ member function, such as Levenshtein."
         src_only_tok += [''] * (n - len(src_only_tok))
         tar_only_tok += [''] * (n - len(tar_only_tok))
 
-        starred = np.zeros((n, n), dtype=np.bool)
-        primed = np.zeros((n, n), dtype=np.bool)
-        row_covered = np.zeros(n, dtype=np.bool)
-        col_covered = np.zeros(n, dtype=np.bool)
+        starred = np.zeros((n, n), dtype=np.bool_)
+        primed = np.zeros((n, n), dtype=np.bool_)
+        row_covered = np.zeros(n, dtype=np.bool_)
+        col_covered = np.zeros(n, dtype=np.bool_)
 
         orig_sim = 1 - np.copy(arr)
         # Preliminaries:
